bayespy.inference.vmp.nodes.gaussian.GaussianWishartDistribution.plates_to_parent
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianWishartDistribution.plates_to_parent